@@ -60,8 +60,9 @@ NODE_SHELF = fn.Shelf(
 )
 
 REACT_PLUGIN = {
-    "module": os.path.join(os.path.dirname(__file__), "react_plugin", "js", "main.js"),
+    "module": os.path.join(os.path.dirname(__file__), "react_plugin", "main.js"),
+    "css": [os.path.join(os.path.dirname(__file__), "react_plugin", "style.css")],
 }
 
 
-__version__ = "0.2.5"
+__version__ = "0.2.6"
